@@ -1,3 +1,4 @@
+# coding=utf-8
 #
 # Copyright 2012 keyes.ie
 #
@@ -17,7 +18,8 @@ def from_timestamp_property(func_to_decorate):
     def wrapper(instance):
         """ Closure that converts from timestamp to datetime. """
         value = func_to_decorate(instance)
-        return datetime.fromtimestamp(value)
+        if value:
+            return datetime.fromtimestamp(value)
     return wrapper
 
 def to_timestamp_property(func_to_decorate):
@@ -26,7 +28,8 @@ def to_timestamp_property(func_to_decorate):
     @functools.wraps(func_to_decorate)
     def wrapper(instance, value):
         """ Closure that converts from datetime to timestamp. """
-        value = time.mktime(value.timetuple())
+        if value:
+            value = time.mktime(value.timetuple())
         func_to_decorate(instance, value)
     return wrapper
 
@@ -34,7 +37,9 @@ from .intercom import AuthenticationError
 from .intercom import Intercom
 from .intercom import ResourceNotFound
 from .intercom import ServerError
+from .intercom import VERSION
 
 from .impression import Impression
 from .message_thread import MessageThread
+from .note import Note
 from .user import User
