@@ -1,3 +1,4 @@
+# coding=utf-8
 #
 # Copyright 2012 keyes.ie
 #
@@ -17,7 +18,10 @@ import functools
 import json
 import requests
 
+
 DEFAULT_TIMEOUT = 10 # seconds
+VERSION = "0.2.7"
+
 
 class IntercomError(StandardError):
     """ Base error. """
@@ -75,8 +79,11 @@ class Intercom(object):
         """ Construct an API request, send it to the API, and parse the response. """
 
         req_params = {}
-        headers = { 'User-Agent': 'python-intercom/0.2.6', 'Accept': 'application/json' }
-        if method in ('POST', 'PUT', 'DELETE'):
+        headers = {
+            'User-Agent': 'python-intercom/' + VERSION,
+            'Accept': 'application/json'
+        }
+        if method in ('POST', 'PUT'):
             headers['content-type'] = 'application/json'
             req_params['data'] = json.dumps(params)
         elif method == 'GET':
@@ -191,6 +198,23 @@ class Intercom(object):
                 params=params)
         return user_dict
 
+    @classmethod
+    def create_note(cls, user_id=None, email=None, body=None):
+        """ Create a note.
+
+        >>> result = Intercom.create_note(email="somebody@example.com",
+        ... body="This is the text of my note.")
+        >>> result['html']
+        u'<p>This is the text of my note.</p>'
+        >>> result['user']['email']
+        u'somebody@example.com'
+
+        """
+        params = { 'email': email, 'user_id': user_id, 'body': body }
+        user_dict = Intercom._call('POST', Intercom.api_endpoint + 'users/notes',
+                params=params)
+        return user_dict
+
     @classmethod
     def get_message_threads(cls, user_id=None, email=None, thread_id=None):
         """ If a thread_id is specified, this returns a specific MessageThread
