@@ -1,10 +1,10 @@
+# coding=utf-8
 #
 # Copyright 2012 keyes.ie
 #
 # License: http://jkeyes.mit-license.org/
 #
 
-import os
 import time
 
 from datetime import datetime
